@@ -1,24 +1,16 @@
-import xml.etree.ElementTree as ET
 import os
+import xml.etree.ElementTree as ET
 
-from firstimpression.constants import APIS, TEMP_FOLDER, ENGLISH_INDEX, REPLACE_DICT, TAGS_TO_REMOVE, LOCAL_INTEGRATED_FOLDER
-from firstimpression.file import update_directories_api, xml_to_root, check_too_old, write_root_to_xml_files, list_files_dir
-from firstimpression.text import replace_html_entities, remove_tags_from_string
-from firstimpression.rss import get_feed
-from firstimpression.time import change_language, parse_string_to_string
-from firstimpression.scala import variables, Log
-
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'BBC'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.api.request import give_error_message, request
+from firstimpression.constants import APIS, REPLACE_DICT, TAGS_TO_REMOVE
+from firstimpression.file import (check_too_old, create_directories,
+                                  purge_directories)
+from firstimpression.placeholder import update_placeholders
+from firstimpression.scala import ScalaPlayer
+from firstimpression.text import remove_tags_from_string, replace_html_entities
+from firstimpression.time import parse_string_to_string
+from firstimpression.xml import path_to_root
+from requests.models import Response
 
 ##################################################################################################
 # CONSTANTS
@@ -26,8 +18,6 @@ error = Log('ERROR', script)
 
 NAME = APIS['bbc']
 
-LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME)
-
 DATETIME_FORMAT = "%a, %d %b %Y %H:%M:%S GMT"
 DATETIME_ABREVIATION_FORMAT = '%b %d %Y %H:%M'
 DATETIME_FULL_FORMAT = '%B %d %Y %H:%M'
@@ -42,70 +32,88 @@ TAGS = {
     'pubDate': 'pubDate'
 }
 
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
 
-def run_api(news_category, minimal_items):
-    debug.log('folder name: {}'.format(NAME))
-    xml_temp_path = os.path.join(TEMP_FOLDER,
-                                 NAME,
-                                 '{}.xml'.format(news_category))
-    
-    debug.log('file path {}: {}'.format(news_category, xml_temp_path))
+def run_api():
+    scala.debug('folder name: {}'.format(NAME))
+
+    news_category = scala.variables['news_category']
+    minimal_items = scala.variables['minimal_items']
+
+    xml_file_name = '{}.xml'.format(news_category)
+    xml_temp_path = os.path.join(scala.temp_folder, xml_file_name)
+
+    scala.debug('file path {}: {}'.format(news_category, xml_temp_path))
 
     url = 'http://feeds.bbci.co.uk/news/{}/rss.xml'.format(news_category)
     minimal_items = MAX_ITEMS if minimal_items > MAX_ITEMS else minimal_items
 
-    debug.log('url: {}'.format(url))
-    debug.log('minimal_items: {}'.format(minimal_items))
+    scala.debug('url: {}'.format(url))
+    scala.debug('minimal_items: {}'.format(minimal_items))
 
-    update_directories_api(NAME)
-    change_language(ENGLISH_INDEX)
+    create_directories([scala.temp_folder, scala.content_folder])
+    purge_directories([scala.temp_folder, scala.content_folder], max_days=1)
+    update_placeholders()
+    scala.set_language('EN')
 
     if check_too_old(xml_temp_path, MAX_FILE_AGE):
         root = ET.Element("root")
-        feed = get_feed(url)
+        response = request(url)
+
+        if not isinstance(response, Response):
+            message = give_error_message(response)
+            if response['type'] == 'ERROR':
+                scala.error(message)
+            elif response['type'] == 'WARN':
+                scala.warn(message)
+
+            raise SystemExit
+
+        feed = ET.fromstring(response.content)
 
         for news_item in get_news_items(feed):
             root.append(parse_news_item(news_item))
 
             if len(root) == MAX_ITEMS:
-                debug.log('max amount of items reached')
+                scala.debug('max amount of items reached')
                 break
 
         if len(root) >= minimal_items:
-            write_root_to_xml_files(root, xml_temp_path, NAME)
+            temp_path = scala.download_root_temp(root, xml_file_name)
+            scala.install_content(temp_path)
         else:
-            warn.log('root consist out of less than minimal items.')
+            scala.warn('root consist out of less than minimal items.')
     else:
-        debug.log('file not old enough to update')
+        scala.debug('file not old enough to update')
 
 
 def check_api():
-    svars = variables()
+    svars = scala.variables
 
-    for file in list_files_dir(LOCAL_PATH):
-        debug.log('file: {}'.format(file))
-        if 'xml' in file:
-            file_path = os.path.join(LOCAL_PATH, file)
-            debug.log('xml file: {}'.format(file_path))
-            if check_too_old(file_path, MAX_FILE_AGE*2):
-                svars['skipscript'] = True
-                warn.log('file too old to show')
-                break
-            else:
-                svars['skipscript'] = False
+    file_path = scala.find_content(
+        'Content://{}/{}.xml'.format(NAME, svars['news_category']))
 
-                amount_items = len(xml_to_root(file_path))
+    if check_too_old(file_path, MAX_FILE_AGE*2):
+        svars['skipscript'] = True
+        scala.debug('file too old')
+    else:
+        svars['skipscript'] = False
 
-                if amount_items == 0:
-                    warn.log('no items found in xml file')
-                    svars['skipscript'] = True
-                    break
+        total_items = len(path_to_root(file_path))
+
+        if total_items == 0:
+            svars['skipscript'] = True
+            scala.warn('No items found in xml file')
 
-                svars['total_items'] = amount_items
 
 ##################################################################################################
 # MEDIA FUNCTIONS
@@ -116,23 +124,23 @@ def check_api():
 # GET FUNCTIONS
 ##################################################################################################
 
-def get_news_items(root):
+def get_news_items(root: ET.Element):
     return root.findall(TAGS['item'])
 
 
-def get_news_title(news_item):
+def get_news_title(news_item: ET.Element):
     return replace_html_entities(REPLACE_DICT, news_item.findtext(TAGS['title'], ''))
 
 
-def get_news_description(news_item):
+def get_news_description(news_item: ET.Element):
     return remove_tags_from_string(TAGS_TO_REMOVE, news_item.findtext(TAGS['descr'], ''))
 
 
-def get_short_date(news_item):
+def get_short_date(news_item: ET.Element):
     return parse_string_to_string(news_item.findtext(TAGS['pubDate'], ''), DATETIME_FORMAT, DATETIME_ABREVIATION_FORMAT)
 
 
-def get_full_date(news_item):
+def get_full_date(news_item: ET.Element):
     return parse_string_to_string(news_item.findtext(TAGS['pubDate'], ''), DATETIME_FORMAT, DATETIME_FULL_FORMAT)
 
 ##################################################################################################
@@ -140,13 +148,13 @@ def get_full_date(news_item):
 ##################################################################################################
 
 
-def parse_news_item(news_item):
+def parse_news_item(news_item: ET.Element):
     item = ET.Element("item")
     ET.SubElement(item, "title").text = get_news_title(news_item)
     ET.SubElement(item, "descr").text = get_news_description(news_item)
     ET.SubElement(item, "pubDate").text = get_short_date(news_item)
     ET.SubElement(item, "fullMonthPubDate").text = get_full_date(news_item)
 
-    debug.log('item: {}'.format(item))
+    scala.debug('item: {}'.format(item))
 
     return item
