@@ -1,11 +1,11 @@
 import os
+from typing import Any
 import xml.etree.ElementTree as ET
 
 import lxml.html
 from firstimpression.api.request import give_error_message, request
 from firstimpression.constants import APIS
-from firstimpression.file import (check_too_old, create_directories,
-                                  purge_directories)
+from firstimpression.file import check_too_old, create_directories, purge_directories
 from firstimpression.placeholder import update_placeholders
 from firstimpression.scala import ScalaPlayer
 from requests import Response
@@ -14,10 +14,10 @@ from requests import Response
 # CONSTANTS
 ##################################################################################################
 
-NAME = APIS['eindhoven']
-URL = 'https://www.eindhovenairport.nl/nl/vertrektijden'
+NAME = APIS["eindhoven"]
+URL = "https://www.eindhovenairport.nl/nl/vertrektijden"
 
-XML_FILENAME = 'flights.xml'
+XML_FILENAME = "flights.xml"
 MAX_FILE_AGE = 60 * 10
 
 TABLE_FLIGHTS_XPATH = '//div[@id="skyguide"]/div/table'
@@ -35,10 +35,10 @@ XML_TEMP_PATH = os.path.join(scala.temp_folder, XML_FILENAME)
 ##################################################################################################
 
 
-def run_api():
+def run_api() -> None:
 
-    scala.debug('folder name: {}'.format(NAME))
-    scala.debug('temp path: {}'.format(XML_TEMP_PATH))
+    scala.debug("folder name: {}".format(NAME))
+    scala.debug("temp path: {}".format(XML_TEMP_PATH))
 
     create_directories([scala.temp_folder, scala.content_folder])
     purge_directories([scala.temp_folder, scala.content_folder], max_days=1)
@@ -51,27 +51,27 @@ def run_api():
 
         if not isinstance(response, Response):
             message = give_error_message(response)
-            if response['type'] == 'ERROR':
+            if response["type"] == "ERROR":
                 scala.error(message)
-            elif response['type'] == 'WARN':
+            elif response["type"] == "WARN":
                 scala.warn(message)
 
             raise SystemExit
 
-        response = lxml.html.fromstring(response.text)
+        response_text: Any = lxml.html.fromstring(response.text)
 
-        table = response.xpath(TABLE_FLIGHTS_XPATH)[0]
+        table = response_text.xpath(TABLE_FLIGHTS_XPATH)[0]
 
-        for row in table.xpath('tr'):
+        for row in table.xpath("tr"):
             item = ET.Element("item")
             store = False
             column_number = 1
 
-            for column in row.xpath('td'):
-                column_text = column.xpath('text()')
+            for column in row.xpath("td"):
+                column_text = column.xpath("text()")
 
                 if len(column_text) == 0:
-                    column_text.append('')
+                    column_text.append("")
 
                 if column_number == 1:
                     ET.SubElement(item, "departure_time").text = column_text[0]
@@ -82,8 +82,9 @@ def run_api():
                 elif column_number == 4:
                     ET.SubElement(item, "status").text = column_text[0]
                     if not "Vertrokken" in column_text[0]:
-                        scala.debug('flight {} already left'.format(
-                            item.findtext('flight_number')))
+                        scala.debug(
+                            "flight {} already left".format(item.findtext("flight_number"))
+                        )
                         store = True
                 elif column_number == 5:
                     pass
@@ -96,20 +97,19 @@ def run_api():
         temp_path = scala.download_root_temp(root, XML_FILENAME)
         scala.install_content(temp_path)
     else:
-        scala.debug('File not old enough to update')
+        scala.debug("File not old enough to update")
 
 
-def check_api():
+def check_api() -> None:
     svars = scala.variables
 
-    file_path = scala.find_content(
-        'Content://{}/{}'.format(NAME, XML_FILENAME))
+    file_path = scala.find_content("Content://{}/{}".format(NAME, XML_FILENAME))
 
-    if check_too_old(file_path, MAX_FILE_AGE*2):
-        svars['skipscript'] = True
-        scala.debug('file too old')
+    if check_too_old(file_path, MAX_FILE_AGE * 2):
+        svars["skipscript"] = True
+        scala.debug("file too old")
     else:
-        svars['skipscript'] = False
+        svars["skipscript"] = False
 
 
 ##################################################################################################
