@@ -80,7 +80,7 @@ def run_api():
         for post in response_json:
             item = ET.SubElement(root, "item")
             ET.SubElement(item, "likes").text = str(
-                get_reactions(post).get('likes', 0))
+                get_reactions(post))
             ET.SubElement(item, "message").text = crop_message(
                 remove_emoji(get_message(post)), max_characters)
             ET.SubElement(item, "created_time").text = parse_string_to_string(
@@ -135,7 +135,7 @@ def get_image(post: Dict[str, Any]):
 
 
 def get_reactions(post: Dict[str, Any]):
-    return post.get('reactions', {})
+    return post.get('likes', 0)
 
 
 def get_message(post: Dict[str, Any]):
