@@ -86,17 +86,19 @@ def run_api():
 
             root = ET.fromstring(response.content)
 
-            for image_original in root.iter('image_original'):
+            for image_original in root.iter('media'):
                 if isinstance(image_original.text, str):
                     temp_path = scala.download_media_temp(image_original.text)
                     image_original.text = scala.install_content(
                         temp_path, category)
+                    image_original.tag = 'image_original'
 
-            for image_square in root.iter('image_square'):
+            for image_square in root.iter('media_sqr'):
                 if isinstance(image_square.text, str):
                     temp_path = scala.download_media_temp(image_square.text)
                     image_square.text = scala.install_content(
                         temp_path, category)
+                    image_square.tag = 'image_square'
 
             temp_path = scala.download_root_temp(root, xml_filename)
             scala.install_content(temp_path)
