@@ -90,14 +90,12 @@ def run_api():
                     temp_path = scala.download_media_temp(image_original.text)
                     image_original.text = scala.install_content(
                         temp_path, category)
-                    image_original.tag = 'image_original'
 
             for image_square in root.iter('media_sqr'):
                 if isinstance(image_square.text, str):
                     temp_path = scala.download_media_temp(image_square.text)
                     image_square.text = scala.install_content(
                         temp_path, category)
-                    image_square.tag = 'image_square'
 
             temp_path = scala.download_root_temp(root, xml_filename)
             scala.install_content(temp_path)
@@ -113,7 +111,7 @@ def check_api():
     keys = svars.keys()
 
     for key in keys:
-        if not 'item' in key and not 'playlist' in key.lower() and not 'skipscript' in key:
+        if not 'item' in key and not 'playlist' in key.lower() and not 'skipscript' in key and not 'reset' in key:
             if isinstance(svars[key], bool):
                 if not 'Player' in key and bool(svars[key]):
                     news_categories.append(key)
