@@ -131,8 +131,10 @@ class ScalaPlayer:
             path = content_path.string
             del content_path
             return path
-        else:
+        elif not self.is_main:
             self.error('The path "{}" does not exists'.format(path))
+        else:
+            print('searched for absolute path')
 
     def install_content(self, abspath: str, subsubfolders: Optional[str] = None):
         if not os.path.isfile(abspath):
